@@ -54,14 +54,14 @@ getPar<-function(m){
     m$mle<-lapply(m$Par$real[distnames],function(x) x$est)
     for(i in distnames){
       if(!is.null(DM[[i]]))
-        m$mle[[i]]<-nw2w((m$Par$beta[[i]]$est-m$conditions$workcons[[i]])^(1/m$conditions$cons[[i]]),m$conditions$workBounds[[i]])
+        m$mle[[i]]<-nw2w(m$Par$beta[[i]]$est,m$conditions$workBounds[[i]])
       else if(dist[[i]] %in% angledists & !m$conditions$estAngleMean[[i]])
         m$mle[[i]]<-m$mle[[i]][-1,]
       Par[[i]] <- c(t(unname(m$mle[[i]])))
     }
     if(nbStates>1){
       beta <- unname(nw2w(m$Par$beta$beta$est,m$conditions$workBounds$beta))
-      if(!length(attr(terms.formula(formDelta),"term.labels")) & is.null(m$conditions$formulaDelta)){
+      if(!length(attr(stats::terms.formula(formDelta),"term.labels")) & is.null(m$conditions$formulaDelta)){
         delta <- unname(m$Par$real$delta$est[1:m$conditions$mixtures,])
       } else {
         delta <- unname(nw2w(m$Par$beta$delta$est,m$conditions$workBounds$delta))
@@ -70,7 +70,7 @@ getPar<-function(m){
         beta <- list(beta=beta,g0=nw2w(m$Par$beta$g0$est,m$conditions$workBounds$g0),theta=nw2w(m$Par$beta$theta$est,m$conditions$workBounds$theta))
       }
       if(m$conditions$mixtures>1){
-        if(!length(attr(terms.formula(formPi),"term.labels")) & is.null(m$conditions$formulaPi)){
+        if(!length(attr(stats::terms.formula(formPi),"term.labels")) & is.null(m$conditions$formulaPi)){
           pie <- unname(m$Par$real$pi$est)
         } else {
           pie <- unname(nw2w(m$Par$beta$pi$est,m$conditions$workBounds$pi))
@@ -84,14 +84,14 @@ getPar<-function(m){
         if(dist[[i]] %in% angledists & !m$conditions$estAngleMean[[i]]) 
           par <- par[-1,]
         par <- c(t(par))
-      } else par <- unname(m$mod$estimate[parindex[[i]]+1:parCount[[i]]])#unname(nw2w((m$CIbeta[[i]]$est-m$conditions$workcons[[i]])^(1/m$conditions$cons[[i]]),m$conditions$workBounds[[i]]))
+      } else par <- unname(m$mod$estimate[parindex[[i]]+1:parCount[[i]]])#unname(nw2w(m$CIbeta[[i]]$est,m$conditions$workBounds[[i]]))
       Par[[i]] <- par
     }
     if(nbStates>1){
       beta <- unname(matrix(m$mod$estimate[parindex[["beta"]]+1:length(m$mle$beta)],nrow(m$mle$beta),ncol(m$mle$beta)))#unname(nw2w(m$mle$beta,m$conditions$workBounds$beta))
-      if(m$conditions$stationary & length(attr(terms.formula(m$conditions$formula),"term.labels"))>0){
+      if(m$conditions$stationary & length(attr(stats::terms.formula(m$conditions$formula),"term.labels"))>0){
         delta <- unname(m$mle$delta)
-      } else if(!length(attr(terms.formula(formDelta),"term.labels")) & is.null(m$conditions$formulaDelta)){
+      } else if(!length(attr(stats::terms.formula(formDelta),"term.labels")) & is.null(m$conditions$formulaDelta)){
         delta <- unname(m$mle$delta[seq(1,nrow(m$mle$delta),nrow(m$mle$delta)/m$conditions$mixtures),])
       } else {
         delta <- unname(matrix(m$mod$estimate[parindex[["beta"]]+length(m$mle$beta)+length(m$CIbeta$pi$est)+1:length(m$CIbeta$delta$est)],nrow(m$CIbeta$delta$est),ncol(m$CIbeta$delta$est)))#unname(nw2w(m$CIbeta$delta$est,m$conditions$workBounds$delta))
@@ -100,7 +100,7 @@ getPar<-function(m){
         beta <- list(beta=beta,g0=m$mod$estimate[parindex[["beta"]]+length(m$mle$beta)+length(m$CIbeta$pi$est)+length(m$CIbeta$delta$est)+1:length(m$mle$g0)],theta=m$mod$estimate[parindex[["beta"]]+length(m$mle$beta)+length(m$CIbeta$pi$est)+length(m$CIbeta$delta$est)+length(m$mle$g0)+1:length(m$mle$theta)])
       }
       if(m$conditions$mixtures>1){
-        if(!length(attr(terms.formula(formPi),"term.labels")) & is.null(m$conditions$formulaPi)){
+        if(!length(attr(stats::terms.formula(formPi),"term.labels")) & is.null(m$conditions$formulaPi)){
           pie <- unname(m$mle$pi[1,])
         } else {
           pie <- unname(matrix(m$mod$estimate[parindex[["beta"]]+length(m$mle$beta)+1:length(m$CIbeta$pi$est)],nrow(m$CIbeta$pi$est),ncol(m$CIbeta$pi$est)))#unname(nw2w(m$CIbeta$pi$est,m$conditions$workBounds$pi))
